@@ -52,6 +52,7 @@ from google.cloud.bigquery_migration_v2.types.translation_config import (
     BigQueryDialect,
     Dialect,
     HiveQLDialect,
+    MySQLDialect,
     NameMappingKey,
     NameMappingValue,
     NetezzaDialect,
@@ -96,6 +97,7 @@ __all__ = (
     "BigQueryDialect",
     "Dialect",
     "HiveQLDialect",
+    "MySQLDialect",
     "NameMappingKey",
     "NameMappingValue",
     "NetezzaDialect",
