@@ -33,6 +33,7 @@ __protobuf__ = proto.module(
         "SQLServerDialect",
         "PostgresqlDialect",
         "PrestoDialect",
+        "MySQLDialect",
         "ObjectNameMappingList",
         "ObjectNameMapping",
         "NameMappingKey",
@@ -170,6 +171,10 @@ class Dialect(proto.Message):
         presto_dialect (google.cloud.bigquery_migration_v2.types.PrestoDialect):
             The Presto dialect
 
+            This field is a member of `oneof`_ ``dialect_value``.
+        mysql_dialect (google.cloud.bigquery_migration_v2.types.MySQLDialect):
+            The MySQL dialect
+
             This field is a member of `oneof`_ ``dialect_value``.
     """
 
@@ -251,6 +256,12 @@ class Dialect(proto.Message):
         oneof="dialect_value",
         message="PrestoDialect",
     )
+    mysql_dialect = proto.Field(
+        proto.MESSAGE,
+        number=14,
+        oneof="dialect_value",
+        message="MySQLDialect",
+    )
 
 
 class BigQueryDialect(proto.Message):
@@ -323,6 +334,10 @@ class PrestoDialect(proto.Message):
     r"""The dialect definition for Presto."""
 
 
+class MySQLDialect(proto.Message):
+    r"""The dialect definition for MySQL."""
+
+
 class ObjectNameMappingList(proto.Message):
     r"""Represents a map of name mappings using a list of key:value
     proto messages of existing name to desired output name.
